core/finance/finance library

Enums

CCType
card enum called CCType with 4 values: visa, mastercard, americanExpress, discover.

Functions

cc({CCType? ccType, int? visaLength}) → String
It takes in a credit card type and a length, and returns a valid credit card number
ccType() → CCType
It returns a random value from the CCType enum.
cedi({int? max, int? min, int? fixed}) → String
It returns a random number between the min and max values, with a fixed number of decimal places
currency({String? currencyKeyToRemove}) → Currency
It takes a currency key to remove from the list of currencies, decodes the base64 encoded string, converts it to a map, removes the currency key if it's not null, converts the map to a list of currencies, and returns a random currency from the list
currencyPair() → List<Currency>
Return a list of two currencies, where the second currency is not the same as the first currency.
dollar({int? max, int? min, int? fixed}) → String
Generate a random dollar amount.
euro({int? max, int? min, int? fixed}) → String
Generate a random euro value
exp() → String
Return a string with the current month and year separated by a dash.
expMonth({bool? future}) → String
Generate a random integer between 1 and 12, or a random integer between the current month and 12 if future is true.
expYear() → String
Generate a random integer between the current year and the current year plus 10.
naira({int? max, int? min, int? fixed}) → String
It returns a random number between the min and max values, with a fixed number of decimal places