core/location/location library

Functions

address() → Address
It takes the addresses string, decodes it, parses it into a map, converts the map into a list of addresses, and returns a random address from that list
areaCode() → String
Return the country code of the current locale, or an empty string if it's not available.
city() → String
Return the city of the address of the user.
coordinates() → Coordinate
Return the coordinates of the address of the user.
country() → Country
It returns a random country from a list of countries.
geohash() → String
It takes a random address, gets the coordinates, and then uses the GeoHasher library to encode those coordinates into a geohash
latitude() → double
Return the latitude of the address of the current user.
locale() → String
It returns the state of a random address.
longitude() → double
Return the longitude of a randomly generated address.
phone([String? temp]) → String
It generates a random phone number.
postal() → String
It takes a base64 encoded JSON string, decodes it, converts it to a map, gets the keys of the map, converts the keys to a list, and returns a random key from the list
postCode() → String
Return a random postal code.
state() → String
Return the state of a generated address.
street() → String
Return a randomly generated address street.