Address class

a model representation of an address

Constructors

Address({required String? address1, required String? address2, required String? city, required String? postalCode, required Coordinate? coordinates, required String? state})
const
Address.fromJson(String source)
It converts a JSON string into a Map object.
factory
Address.fromMap(Map<String, dynamic> map)
Address.fromMap is a factory constructor that takes a Map<String, dynamic> and returns an Address object
factory

Properties

address1 → String?
final
address2 → String?
final
city → String?
final
coordinates → Coordinate?
final
hashCode → int
The hash code for this object.
no setterinherited
postalCode → String?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
final
stringify → bool
If set to true, the toString method will be overridden to output this instance's props.
no setter

Methods

copyWith({String? address1, String? address2, String? city, String? postalCode, Coordinate? coordinates, String? state}) → Address
Return a new Address object with the same values as this one, except for the values that are explicitly overridden.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
It converts the object to a map.
toMap() → Map<String, dynamic>
It converts the object into a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited