User class

Constructors

User({String? gender, Name? name, Location? location, String? username, String? password, String? salt, String? md5, String? sha1, String? sha256, num? registered, num? dob, String? phone, String? cell, String? pps, Picture? picture})
const
User.fromJson(String source)
It converts a JSON string into a User object.
factory
User.fromMap(Map<String, dynamic> map)
It creates a User object from a map.
factory

Properties

cell → String?
final
dob → num?
final
gender → String?
final
hashCode → int
The hash code for this object.
no setterinherited
location → Location?
final
md5 → String?
final
name → Name?
final
password → String?
final
phone → String?
final
picture → Picture?
final
pps → String?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
registered → num?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salt → String?
final
sha1 → String?
final
sha256 → String?
final
stringify → bool
If set to true, the toString method will be overridden to output this instance's props.
no setter
username → String?
final

Methods

copyWith({String? gender, Name? name, Location? location, String? username, String? password, String? salt, String? md5, String? sha1, String? sha256, num? registered, num? dob, String? phone, String? cell, String? pps, Picture? picture}) → User
It creates a new User object with the same values as the current User object, but with the values of the parameters replacing the values of the current User object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
It converts the object to a map.
toMap() → Map<String, dynamic>
It converts the object to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited