core/text/text library

Functions

paragraph({int? sentences, bool lineBreak = true}) → String
It generates a paragraph of sentences.
sentence() → String
It returns a random sentence from the list of sentences
syllable(String count) → String
It takes a string, decodes it from base64, parses it as JSON, and returns a random element from the list of syllables that matches the input string
word() → String
"Return a random word from the list of words."