core/time/time library

Functions

amPm() → String
Return a random element from a list containing the am and pm value.
date() → String
Return a string containing the current day, month, and year, separated by dashes.
hour() → int
Returns a random integer between 0 and 999.
millisecond() → int
Returns a random integer between 0 and 999.
minute() → int
Returns a random integer between 0 and 60.
month() → String
returns a month of the year Return a random month of the year.
second() → int
Return a random integer between 0 and 60.
timeStamp() → String
It returns a string that represents the current time in microseconds
weekday() → String
Return a random weekday.
year({int? max, int? min = 1701}) → String
Generate a random year between 1701 and the current year.